'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var pos = function pos(element) {
  return {
    top: element.offsetTop,
    left: element.offsetLeft
  };
};

var dim = function dim(element) {
  return {
    height: element.offsetHeight,
    width: element.offsetWidth
  };
};

var offset = function offset(trigger, body) {
  var triggerDetails = {
    pos: pos(trigger),
    dim: dim(trigger)
  };

  var bodyDetails = {
    pos: pos(body),
    dim: dim(body)
  };

  var top = triggerDetails.pos.top - bodyDetails.dim.height;
  var left = triggerDetails.pos.left;
  var bottom = triggerDetails.pos.top + triggerDetails.dim.height;
  var right = left - (bodyDetails.dim.width - triggerDetails.dim.width);

  var horCenter = left - (bodyDetails.dim.width - triggerDetails.dim.width) / 2;
  var verCenter = bottom - (bodyDetails.dim.height + triggerDetails.dim.height) / 2;

  var position = {
    top: top,
    bottom: bottom,
    left: left,
    right: right,

    'bottom-left': { top: bottom, left: left },
    'bottom-center': { top: bottom, left: horCenter },
    'bottom-right': { top: bottom, left: right },

    'top-left': { top: top, left: left },
    'top-center': { top: top, left: horCenter },
    'top-right': { top: top, left: right },

    'left-top': { top: top, left: left - bodyDetails.dim.width },
    'left-center': { top: verCenter, left: left - bodyDetails.dim.width },
    'left-bottom': { top: bottom, left: left - bodyDetails.dim.width },

    'right-top': { top: top, left: right + bodyDetails.dim.width },
    'right-center': { top: verCenter, left: right + bodyDetails.dim.width },
    'right-bottom': { top: bottom, left: right + bodyDetails.dim.width }
  };

  return function (prop) {
    console.dir(position);
    return position[prop] || position['bottom-left'];
  };
};

exports.default = {
  dim: dim,
  pos: pos,
  offset: offset
};